@@ -17,6 +17,7 @@ from functools import partial
 
 
 from cognite.client.exceptions import CogniteNotFoundError, CogniteAPIError
+from cognite.client.data_classes import FileMetadataUpdate
 
 from akerbp.mlops.core import config, logger
 from akerbp.mlops.core.helpers import confirm_prompt
@@ -664,10 +665,30 @@ def file_exists(external_id, directory, dataset_id=None):
 def get_dataset_id(external_id):
     """
     Input:
-        -external_id: (str)
+        -external_id: (str) dataset external id, or `None` for no dataset
     Output:
-        -id: (int)
+        -id: (int) dataset id, or `None` for no dataset
+    """
+    if external_id:
+        client = global_client["files"]
+        dataset = client.data_sets.retrieve(external_id=external_id)        
+        return dataset.id
+    else:
+        return None
+
+
+def file_to_dataset(file_external_id, dataset_external_id):
+    """
+    Assign a file to a dataset.
+    Input
+        - file_external_id: (str) the file's external id 
+        - dataset_external_id: (str) the dataset's external id, `None` for no
+            dataset
     """
     client = global_client["files"]
-    dataset = client.data_sets.retrieve(external_id=external_id)
-    return dataset.id
\ No newline at end of file
+    dataset_id = get_dataset_id(dataset_external_id)
+    file_metadata_update = FileMetadataUpdate(external_id=file_external_id)
+    file_metadata_update = file_metadata_update.data_set_id.set(dataset_id)
+    _ = client.files.update(file_metadata_update)
+    logging.info(f"Assigned dataset {dataset_id} to file {file_external_id}")
+
