@@ -42,7 +42,8 @@ def deploy_model(model_settings, platform_methods=platform_methods):
         logging.debug(" ")
         logging.info(f"Deploy model {c.model_name}")
 
-        if service_name == 'prediction':
+        if (service_name == 'prediction') and c.artifact_folder:
+            mm.set_active_dataset(c.dataset)
             c.model_id = mm.set_up_model_artifact(c.artifact_folder, c.model_name)
 
         logging.info("Create deployment folder and move required files/folders")
